@@ -13,5 +13,6 @@ require_once 'Symfony/Polyfill/Php54/autoload.php';
 require_once 'Symfony/Polyfill/Php55/autoload.php';
 require_once 'Symfony/Polyfill/Php56/autoload.php';
 require_once 'Symfony/Polyfill/Php70/autoload.php';
+require_once 'Symfony/Polyfill/Php71/autoload.php';
+require_once 'Symfony/Polyfill/Php72/autoload.php';
 // require_once 'Symfony/Polyfill/Util/autoload.php'; (already required by Php56)
-require_once 'Symfony/Polyfill/Xml/autoload.php';
